Django-Rosetta-Grappelli
===============

Compatibility template for rosetta when grappelli is installed

All credits should go to **Haineault.com** for creating grappelli-fit

Installation
------------

Add rosetta-grappelli **before** `rosetta` in your installed apps:

    INSTALLED_APPS = (
        'grappelli',
        ...
        'rosetta-grappelli',
        'rosetta',
        ...
    )

That's it